#################################################################################
# Created       : Martin Foster
# Modified      : 01/02/2003
#################################################################################
#
# Crypto - Module hiding the complexity behind cryptographic uses
#          in Ethereal Realms
# Copyright (C) 2000-2003  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 204, 817 5TH NE
#                 Calgary, Alberta
#                 T2E 3W9
#
#################################################################################
package Ethereal::Crypto;					# Module name

use strict;							# Strict variable enforcement


#################################################################################
# Data Members
#################################################################################

#################################################################################
# Sub-Routines
#################################################################################

#####################
# Constructor
#
# Allows to class to be exported and thus spawn objects as a result

sub new
{
	####################
	# Program Area
	my $class    = shift;					# Class itself
	my $self;						# Reference to self


	####################
	# Program area

	# Empty hash
	$self = {};	


	# Bless $self into designated class
	bless $self, $class;

	# Return self
	return $self;
}


#####################
# Decrypt Parameter
#
# Will take a reference to a hash, seperate it together using the implausible
# character of a form feed as the seperator

sub DecryptParam
{
	#####################
	# Data members
	my $self	= shift;				# Self referencing html
	my $crypt	= shift;				# Crypted parameter list
	my $hash	= shift;				# Hash value

	my $val;						# Tempotary value
	my @vals;						# Values


	#####################
	# Program area

	# Encode string
	$val = pack('H*', $crypt);

	# Split and return
	@vals = split(/\f/, $val);

	# Populate hash
	while ($val = shift(@vals))
	{ $hash->{$val} = shift(@vals); }


	# Return true
	return 1;
}


#####################
# Encrypt Parameter
#
# Will take a flatened hash (key/pair), join it together using form feed as the
# seperator, encrypt the entire line using the provided key.

sub EncryptParam
{
	#####################
	# Data members
	my $self	= shift;				# Self reference
	my $string;						# String to work on


	#####################
	# Program area

	# Concatenante to string
	$string = join("\f", @_);

	# Encode string
	$string = unpack('H*', $string);

	# Return said string
	return $string;
}


#####################
# MakeSalt
#
# Produces a salt using rand() and the Digest::MD5 hash.  Which once truncated to
# fourteen characters will be returned to parents function.

sub makeSalt
{
	#####################
	# Data members
	my $self;						# Reference to self
	my $salt;						# Salt value

	#####################
	# Program area	
	
	# Generate hash, truncate then return
	$salt = md5_hex(rand());
	return substr($salt, 0, 14);
}

1;								# Return true
